@@ -7,7 +7,7 @@ test_that("palette generation is accurate", {
 
         # options work as expected
         expect_equal(carto_pal(3, name = "Safe"), c("#88CCEE", "#CC6677", "#888888"))
-        expect_equal(carto_pal(3, name = "PurpOr"), c("#f9ddda", "#ce78b3", "#573b88"))
+        expect_equal(carto_pal(3, name = "PurpOr"), toupper(c("#f9ddda", "#ce78b3", "#573b88")))
         expect_equal(carto_pal(2, name = "Burg"), c("#ffc6c4", "#672044"))
         expect_equal(carto_pal(7, "Burg"), carto_pal(name = "Burg"))
 
@@ -18,6 +18,6 @@ test_that("palette generation is accurate", {
 
         # warnings
         expect_warning(carto_pal(2, name = "PurpOr"))
-        expect_warning(carto_pal(12, name = "Burg"))
+        expect_warning(carto_pal(13, name = "Safe"))
 
 })
